@@ -16,7 +16,6 @@
  * @package    Settings
  *
  */
-
 return array(
 	'groups' => array(
 		'system' => array(
@@ -30,36 +29,58 @@ return array(
 					'string_type' => 'dir',
 					'default' => '/var/customers/webs/',
 					'save_method' => 'storeSettingField',
-					'plausibility_check_method' => 'checkPathConflicts'
-					),
+					'plausibility_check_method' => array(
+						'\\Froxlor\\Validate\\Check',
+						'checkPathConflicts'
+					)
+				),
 				'system_documentroot_use_default_value' => array(
 					'label' => $lng['serversettings']['documentroot_use_default_value'],
 					'settinggroup' => 'system',
 					'varname' => 'documentroot_use_default_value',
 					'type' => 'bool',
 					'default' => false,
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_ipaddress' => array(
 					'label' => $lng['serversettings']['ipaddress'],
 					'settinggroup' => 'system',
 					'varname' => 'ipaddress',
 					'type' => 'option',
 					'option_mode' => 'one',
-					'option_options_method' => 'getIpAddresses',
-					'default' => '',
-					'save_method' => 'storeSettingIpAddress',
+					'option_options_method' => array(
+						'\\Froxlor\\Domain\\IpAddr',
+						'getIpAddresses'
 					),
+					'default' => '',
+					'save_method' => 'storeSettingIpAddress'
+				),
 				'system_defaultip' => array(
 					'label' => $lng['serversettings']['defaultip'],
 					'settinggroup' => 'system',
 					'varname' => 'defaultip',
 					'type' => 'option',
 					'option_mode' => 'multiple',
-					'option_options_method' => 'getIpPortCombinations',
-					'default' => '',
-					'save_method' => 'storeSettingDefaultIp',
+					'option_options_method' => array(
+						'\\Froxlor\\Domain\\IpAddr',
+						'getIpPortCombinations'
 					),
+					'default' => '',
+					'save_method' => 'storeSettingDefaultIp'
+				),
+				'system_defaultsslip' => array(
+					'label' => $lng['serversettings']['defaultsslip'],
+					'settinggroup' => 'system',
+					'varname' => 'defaultsslip',
+					'type' => 'option',
+					'option_mode' => 'multiple',
+					'option_options_method' => array(
+						'\\Froxlor\\Domain\\IpAddr',
+						'getSslIpPortCombinations'
+					),
+					'default' => '',
+					'save_method' => 'storeSettingDefaultSslIp'
+				),
 				'system_hostname' => array(
 					'label' => $lng['serversettings']['hostname'],
 					'settinggroup' => 'system',
@@ -67,33 +88,47 @@ return array(
 					'type' => 'string',
 					'default' => '',
 					'save_method' => 'storeSettingHostname',
-					'plausibility_check_method' => 'checkHostname',
-					),
+					'plausibility_check_method' => array(
+						'\\Froxlor\\Validate\\Check',
+						'checkHostname'
+					)
+				),
+				'api_enabled' => array(
+					'label' => $lng['serversettings']['enable_api'],
+					'settinggroup' => 'api',
+					'varname' => 'enabled',
+					'type' => 'bool',
+					'default' => false,
+					'save_method' => 'storeSettingField'
+				),
 				'system_validatedomain' => array(
 					'label' => $lng['serversettings']['validate_domain'],
 					'settinggroup' => 'system',
 					'varname' => 'validate_domain',
 					'type' => 'bool',
 					'default' => true,
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_stdsubdomain' => array(
 					'label' => $lng['serversettings']['stdsubdomainhost'],
 					'settinggroup' => 'system',
 					'varname' => 'stdsubdomain',
 					'type' => 'string',
 					'default' => '',
-					'save_method' => 'storeSettingHostname',
-					),
+					'save_method' => 'storeSettingHostname'
+				),
 				'system_mysql_access_host' => array(
 					'label' => $lng['serversettings']['mysql_access_host'],
 					'settinggroup' => 'system',
 					'varname' => 'mysql_access_host',
 					'type' => 'string',
 					'default' => '127.0.0.1,localhost',
-					'plausibility_check_method' => 'checkMysqlAccessHost',
-					'save_method' => 'storeSettingMysqlAccessHost',
+					'plausibility_check_method' => array(
+						'\\Froxlor\\Validate\\Check',
+						'checkMysqlAccessHost'
 					),
+					'save_method' => 'storeSettingMysqlAccessHost'
+				),
 				'system_nssextrausers' => array(
 					'label' => $lng['serversettings']['nssextrausers'],
 					'settinggroup' => 'system',
@@ -101,7 +136,7 @@ return array(
 					'type' => 'bool',
 					'default' => false,
 					'save_method' => 'storeSettingField'
-					),
+				),
 				'system_index_file_extension' => array(
 					'label' => $lng['serversettings']['index_file_extension'],
 					'settinggroup' => 'system',
@@ -109,28 +144,28 @@ return array(
 					'type' => 'string',
 					'string_regexp' => '/^[a-zA-Z0-9]{1,6}$/',
 					'default' => 'html',
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_store_index_file_subs' => array(
 					'label' => $lng['serversettings']['system_store_index_file_subs'],
 					'settinggroup' => 'system',
 					'varname' => 'store_index_file_subs',
 					'type' => 'bool',
 					'default' => true,
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_httpuser' => array(
 					'settinggroup' => 'system',
 					'varname' => 'httpuser',
 					'type' => 'hidden',
-					'default' => 'www-data',
-					),
+					'default' => 'www-data'
+				),
 				'system_httpgroup' => array(
 					'settinggroup' => 'system',
 					'varname' => 'httpgroup',
 					'type' => 'hidden',
-					'default' => 'www-data',
-					),
+					'default' => 'www-data'
+				),
 				'system_report_enable' => array(
 					'label' => $lng['serversettings']['report']['report'],
 					'settinggroup' => 'system',
@@ -138,8 +173,8 @@ return array(
 					'type' => 'bool',
 					'default' => true,
 					'cronmodule' => 'froxlor/reports',
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_report_webmax' => array(
 					'label' => $lng['serversettings']['report']['webmax'],
 					'settinggroup' => 'system',
@@ -148,8 +183,8 @@ return array(
 					'int_min' => 0,
 					'int_max' => 150,
 					'default' => 90,
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_report_trafficmax' => array(
 					'label' => $lng['serversettings']['report']['trafficmax'],
 					'settinggroup' => 'system',
@@ -158,8 +193,8 @@ return array(
 					'int_min' => 0,
 					'int_max' => 150,
 					'default' => 90,
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 
 				'system_mail_use_smtp' => array(
 					'label' => $lng['serversettings']['mail_use_smtp'],
@@ -167,16 +202,16 @@ return array(
 					'varname' => 'mail_use_smtp',
 					'type' => 'bool',
 					'default' => false,
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_mail_smtp_host' => array(
 					'label' => $lng['serversettings']['mail_smtp_host'],
 					'settinggroup' => 'system',
 					'varname' => 'mail_smtp_host',
 					'type' => 'string',
 					'default' => 'localhost',
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_mail_smtp_port' => array(
 					'label' => $lng['serversettings']['mail_smtp_port'],
 					'settinggroup' => 'system',
@@ -185,41 +220,41 @@ return array(
 					'int_min' => 1,
 					'int_max' => 65535,
 					'default' => 25,
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_mail_smtp_usetls' => array(
 					'label' => $lng['serversettings']['mail_smtp_usetls'],
 					'settinggroup' => 'system',
 					'varname' => 'mail_smtp_usetls',
 					'type' => 'bool',
 					'default' => true,
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_mail_smtp_auth' => array(
 					'label' => $lng['serversettings']['mail_smtp_auth'],
 					'settinggroup' => 'system',
 					'varname' => 'mail_smtp_auth',
 					'type' => 'bool',
 					'default' => true,
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_mail_smtp_user' => array(
 					'label' => $lng['serversettings']['mail_smtp_user'],
 					'settinggroup' => 'system',
 					'varname' => 'mail_smtp_user',
 					'type' => 'string',
 					'default' => '',
-					'save_method' => 'storeSettingField',
-					),
+					'save_method' => 'storeSettingField'
+				),
 				'system_mail_smtp_passwd' => array(
 					'label' => $lng['serversettings']['mail_smtp_passwd'],
 					'settinggroup' => 'system',
 					'varname' => 'mail_smtp_passwd',
 					'type' => 'hiddenString',
 					'default' => '',
-					'save_method' => 'storeSettingField',
-					),
-				),
-			),
-		),
-	);
+					'save_method' => 'storeSettingField'
+				)
+			)
+		)
+	)
+);
